@@ -165,6 +165,12 @@ class BatchJobBase(WDL.runtime.task_container.TaskContainer):
                 assert container_fn.startswith(container_prefix) and len(container_fn) > len(
                     container_prefix
                 )
+                if host_fn.endswith("/"):
+                    assert container_fn.endswith("/")
+                    host_fn = host_fn[:-1]
+                    container_fn = container_fn[:-1]
+                else:
+                    assert not container_fn.endswith("/")
                 link_dn = os.path.dirname(container_fn)
                 if link_dn not in link_dirs_made:
                     os.makedirs(link_dn)
@@ -243,7 +249,8 @@ class BatchJobBase(WDL.runtime.task_container.TaskContainer):
         commands = [
             f"cd {self.container_dir}/work",
             "exit_code=0",
-            "bash -l ../command >> ../stdout.txt 2> >(tee -a ../stderr.txt >&2) || exit_code=$?",
+            self.cfg.get("task_runtime", "command_shell")
+            + " ../command >> ../stdout.txt 2> >(tee -a ../stderr.txt >&2) || exit_code=$?",
         ]
         if self.cfg.get_bool("aws", "container_sync", False):
             commands.append("find . -type f | xargs sync")
@@ -263,7 +270,7 @@ class BatchJobBase(WDL.runtime.task_container.TaskContainer):
             "command": ["/bin/bash", "-ec", "\n".join(commands)],
             "environment": [
                 {"name": ev_name, "value": ev_value}
-                for ev_name, ev_value in self.runtime_values.get("env", dict())
+                for ev_name, ev_value in self.runtime_values.get("env", dict()).items()
             ],
             "resourceRequirements": resource_requirements,
             "privileged": self.runtime_values.get("privileged", False),
